package com.goldenwater.slaj.ttsa.service;

import java.util.List;
import com.goldenwater.slaj.ttsa.domain.BisTtsaCertChaName;

public interface IBisTtsaCertChaNameService {
    BisTtsaCertChaName selectBisTtsaCertChaNameByGuid(String guid);
    List<BisTtsaCertChaName> selectBisTtsaCertChaNameList(BisTtsaCertChaName bisTtsaCertChaName);
    int insertBisTtsaCertChaName(BisTtsaCertChaName bisTtsaCertChaName);
    int updateBisTtsaCertChaName(BisTtsaCertChaName bisTtsaCertChaName);
    int deleteBisTtsaCertChaNameByGuid(String guid);
    int deleteBisTtsaCertChaNameByGuids(String[] guids);
}
